using System;
using System.Drawing;
using System.Windows.Forms;
using Com.Raritan.KxGui.Scan;

namespace Com.Raritan.KxGui.Preferences;

public class ApplicationPreferences
{
	private readonly bool _logEnabled;

	private readonly bool _enableLaunchInFS;

	private readonly int _keyboardType;

	private readonly string _singleMouseExitHotKey;

	private readonly string _keyboardMenuHotKey;

	private readonly string _connectionExitHotKey;

	private readonly int _broadcastPort;

	private readonly string _screen;

	private readonly bool _enableLaunchWithSMM;

	private readonly bool _enableLaunchWithScaling;

	private readonly bool _pinMenuToolbar;

	private readonly int _scanDisplayInterval;

	private readonly int _portScanInterval;

	private readonly Size _scanThumbnailSize;

	private readonly Orientation _scanOrientation;

	public bool LogEnabled => _logEnabled;

	public bool EnableLaunchInFS => _enableLaunchInFS;

	public int KeyboardType => _keyboardType;

	public string SingleMouseExitHotKey => _singleMouseExitHotKey;

	public string KeyboardMenuHotKey => _keyboardMenuHotKey;

	public string ConnectionExitHotKey => _connectionExitHotKey;

	public int BroadcastPort => _broadcastPort;

	public string Screen => _screen;

	public bool EnableLaunchWithSMM => _enableLaunchWithSMM;

	public bool EnableLaunchWithScaling => _enableLaunchWithScaling;

	public bool PinMenuToolbar => _pinMenuToolbar;

	public int ScanDisplayInterval => _scanDisplayInterval;

	public int PortScanInterval => _portScanInterval;

	public Size ScanThumbnailSize => _scanThumbnailSize;

	public Orientation ScanOrientation => _scanOrientation;

	public ApplicationPreferences(bool logEnabled, bool enableLaunchInFS, int keyboardType, string singleMouseExitHotKey, string keyboardMenuHotKey, string connectionExitHotKey, int broadcastPort, string screen, bool enableLaunchWithSMM, bool enableLaunchWithScaling, bool pinMenuToolbar, int scanDisplayInterval, int portScanInterval, Size scanThumbnailSize, Orientation scanOrientation)
	{
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0101: Unknown result type (might be due to invalid IL or missing references)
		//IL_0103: Unknown result type (might be due to invalid IL or missing references)
		XmlApplicationPreferences xmlApplicationPreferences = new XmlApplicationPreferences
		{
			LogEnabled = logEnabled,
			EnableLaunchInFS = enableLaunchInFS,
			KeyboardType = keyboardType,
			SingleMouseExitHotKey = singleMouseExitHotKey,
			KeyboardMenuHotKey = keyboardMenuHotKey,
			ConnectionExitHotKey = connectionExitHotKey,
			BroadcastPort = broadcastPort,
			Monitor = screen,
			EnableLaunchWithSMM = enableLaunchWithSMM,
			EnableLaunchWithScaling = enableLaunchWithScaling,
			PinMenuToolbar = pinMenuToolbar,
			ScanDisplayInterval = scanDisplayInterval,
			PortScanInterval = portScanInterval,
			ScanThumbnailSize = Com.Raritan.KxGui.Scan.b.b(scanThumbnailSize),
			ScanOrientation = Com.Raritan.KxGui.Scan.b.b(scanOrientation)
		};
		_logEnabled = logEnabled;
		_enableLaunchInFS = enableLaunchInFS;
		_keyboardMenuHotKey = keyboardMenuHotKey;
		_singleMouseExitHotKey = singleMouseExitHotKey;
		_singleMouseExitHotKey = singleMouseExitHotKey;
		_connectionExitHotKey = connectionExitHotKey;
		_keyboardType = keyboardType;
		_broadcastPort = broadcastPort;
		_screen = screen;
		_enableLaunchWithSMM = enableLaunchWithSMM;
		_enableLaunchWithScaling = enableLaunchWithScaling;
		_pinMenuToolbar = pinMenuToolbar;
		_scanDisplayInterval = scanDisplayInterval;
		_portScanInterval = portScanInterval;
		_scanThumbnailSize = scanThumbnailSize;
		_scanOrientation = scanOrientation;
	}

	public override string ToString()
	{
		//IL_01d8: Unknown result type (might be due to invalid IL or missing references)
		return "ApplicationPreferences : " + Environment.NewLine + "LogEnabled : " + LogEnabled + Environment.NewLine + "EnableLaunchInFS : " + EnableLaunchInFS + Environment.NewLine + "KeyboardType : " + KeyboardType + Environment.NewLine + "SingleMouseExitHotKey : " + SingleMouseExitHotKey + Environment.NewLine + "KeyboardMenuHotKey : " + KeyboardMenuHotKey + Environment.NewLine + "ConnectionExitHotKey : " + ConnectionExitHotKey + Environment.NewLine + "BroadcastPort : " + BroadcastPort + Environment.NewLine + "Screen : " + Screen + Environment.NewLine + "EnableLaunchWithSMM : " + EnableLaunchWithSMM + Environment.NewLine + "EnableLaunchWithScaling : " + EnableLaunchWithScaling + Environment.NewLine + "PinMenuToolbar : " + PinMenuToolbar + Environment.NewLine + "ScanDisplayInterval : " + ScanDisplayInterval + Environment.NewLine + "PortScanInterval : " + PortScanInterval + Environment.NewLine + "ScanThumbnailSize : " + Com.Raritan.KxGui.Scan.b.b(ScanThumbnailSize) + Environment.NewLine + "ScanOrientation : " + Com.Raritan.KxGui.Scan.b.b(ScanOrientation);
	}

	public override bool Equals(object obj)
	{
		//IL_0124: Unknown result type (might be due to invalid IL or missing references)
		//IL_012a: Unknown result type (might be due to invalid IL or missing references)
		if (obj != null && obj.GetType().Equals(typeof(ApplicationPreferences)))
		{
			ApplicationPreferences applicationPreferences = obj as ApplicationPreferences;
			if (LogEnabled == applicationPreferences.LogEnabled && EnableLaunchInFS == applicationPreferences.EnableLaunchInFS && KeyboardType == applicationPreferences.KeyboardType && object.Equals(SingleMouseExitHotKey, applicationPreferences.SingleMouseExitHotKey) && object.Equals(SingleMouseExitHotKey, applicationPreferences.SingleMouseExitHotKey) && object.Equals(ConnectionExitHotKey, applicationPreferences.ConnectionExitHotKey) && BroadcastPort == applicationPreferences.BroadcastPort && object.Equals(Screen, applicationPreferences.Screen) && EnableLaunchWithSMM == applicationPreferences.EnableLaunchWithSMM && EnableLaunchWithScaling == applicationPreferences.EnableLaunchWithScaling && PinMenuToolbar == applicationPreferences.PinMenuToolbar && ScanDisplayInterval == applicationPreferences.ScanDisplayInterval && PortScanInterval == applicationPreferences.PortScanInterval && object.Equals(ScanThumbnailSize, applicationPreferences.ScanThumbnailSize))
			{
				return ScanOrientation == applicationPreferences.ScanOrientation;
			}
			return false;
		}
		return false;
	}

	public override int GetHashCode()
	{
		return base.GetHashCode();
	}
}
