using System;
using System.Collections.Generic;
using System.IO;
using System.Xml;
using System.Xml.Serialization;
using System.Xml.XPath;
using Com.Raritan.KxGui.Scan;
using log4net;

namespace Com.Raritan.KxGui.Preferences;

public class ApplicationPreferencesManager
{
	public delegate void AppPreferencesChanged(ApplicationPreferencesManager manager);

	private class HotKeyResolveInfoHolder
	{
		private readonly Func<bool> _isUserDefHotKeyFn;

		private readonly Func<string> _getHotKeyFn;

		private readonly char _defHotKey;

		public Func<bool> IsUserDefHotKeyFn => _isUserDefHotKeyFn;

		public Func<string> GetHotKeyFn => _getHotKeyFn;

		public char DefHotKey => _defHotKey;

		public string ResolvedHotKey { get; set; }

		public HotKeyResolveInfoHolder(Func<bool> isUserDefHotKeyFn, Func<string> getHotKeyFn, char defHotKey)
		{
			_isUserDefHotKeyFn = isUserDefHotKeyFn;
			_getHotKeyFn = getHotKeyFn;
			_defHotKey = defHotKey;
		}
	}

	private static readonly string Filepath = Path.Combine(Utils.HOME_DIR, "ApplicationSettings.xml");

	private static readonly ILog Logger = LogManager.GetLogger(typeof(ApplicationPreferencesManager));

	public ApplicationPreferences AppPreferences { get; private set; }

	public event AppPreferencesChanged LogOptionEvent = delegate
	{
	};

	public event AppPreferencesChanged FullScreenOptionEvent = delegate
	{
	};

	public event AppPreferencesChanged SingleMouseOptionEvent = delegate
	{
	};

	public event AppPreferencesChanged ConnectionExitOptionEvent = delegate
	{
	};

	public ApplicationPreferencesManager()
	{
		//IL_0105: Unknown result type (might be due to invalid IL or missing references)
		XmlApplicationPreferences xmlApplicationPreferences = LoadPreferences();
		HotKeyResolveInfoHolder[] array = ResolveHotKeys(xmlApplicationPreferences);
		AppPreferences = new ApplicationPreferences(xmlApplicationPreferences.LogEnabled, xmlApplicationPreferences.EnableLaunchInFS, xmlApplicationPreferences.KeyboardType, array[0].ResolvedHotKey, array[1].ResolvedHotKey, array[2].ResolvedHotKey, xmlApplicationPreferences.BroadcastPort, xmlApplicationPreferences.Monitor, xmlApplicationPreferences.EnableLaunchWithSMM, xmlApplicationPreferences.EnableLaunchWithScaling, xmlApplicationPreferences.PinMenuToolbar, xmlApplicationPreferences.ScanDisplayInterval, xmlApplicationPreferences.PortScanInterval, Com.Raritan.KxGui.Scan.b.d(xmlApplicationPreferences.ScanThumbnailSize), Com.Raritan.KxGui.Scan.b.b(xmlApplicationPreferences.ScanOrientation));
	}

	private static XmlApplicationPreferences LoadPreferences()
	{
		//IL_0043: Unknown result type (might be due to invalid IL or missing references)
		//IL_0049: Expected O, but got Unknown
		XmlDocument xmlDocument = Utils.GetXmlDocument(Filepath);
		if (xmlDocument == null)
		{
			Logger.Debug(Filepath + " not found, using default ApplicationPreferences");
			return new XmlApplicationPreferences();
		}
		string transformedXml = Utils.GetTransformedXml("ToAppPreferences.xslt", (IXPathNavigable)(object)xmlDocument);
		XmlSerializer val = new XmlSerializer(typeof(XmlApplicationPreferences));
		try
		{
			return (XmlApplicationPreferences)val.Deserialize((TextReader)new StringReader(transformedXml));
		}
		catch (InvalidOperationException exception)
		{
			Logger.Warn("Error Reading ApplicationPreferences, using default", exception);
			return new XmlApplicationPreferences();
		}
	}

	public void PersistAppPreferences(ApplicationPreferences pref)
	{
		XmlDocument val = Utils.GetXmlDocument(Filepath);
		XPathNavigator val2;
		if (val == null)
		{
			val = Utils.GetPrefernecesTemplate("AppPreferencesTemplate.xml");
			val2 = ((XmlNode)val).CreateNavigator();
		}
		else
		{
			val2 = ((XmlNode)val).CreateNavigator();
			XPathNavigator val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='LogJac']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='AlwaysOpenFS']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='keyboardType']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='SingleMouseExitHotKey']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='KeyboardShortcutMenuHotKey']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='ConnectionExitHotKey']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='broadcastPort']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='monitor_akc']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='AlwaysOpenSingleMouseMode']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='AlwaysOpenScale']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='PinMenuToolbar']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='ScanDisplayInterval']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='PortScanInterval']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='ScanThumbnailSize']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map/entry[@key='ScanOrientation']");
			if (val3 != null)
			{
				val3.DeleteSelf();
			}
		}
		XPathNavigator val4 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map");
		if (val4 == null)
		{
			val = Utils.GetPrefernecesTemplate("AppPreferencesTemplate.xml");
			val2 = ((XmlNode)val).CreateNavigator();
			val4 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='ApplicationSettings']/map");
		}
		string data = Utils.Serialize(new XmlApplicationPreferences(pref));
		val4.AppendChild(Utils.GetTransformedXml("FromAppPreferences.xslt", data));
		ApplicationPreferences appPreferences = AppPreferences;
		AppPreferences = pref;
		FireEvents(appPreferences);
		try
		{
			val.Save(Filepath);
		}
		catch (Exception exception)
		{
			Logger.Warn("Falied to persist " + Filepath, exception);
			throw;
		}
	}

	private void FireEvents(ApplicationPreferences oldPrefs)
	{
		ApplicationPreferences appPreferences = AppPreferences;
		if (oldPrefs.LogEnabled != appPreferences.LogEnabled)
		{
			this.LogOptionEvent(this);
		}
		if (!oldPrefs.KeyboardMenuHotKey.Equals(appPreferences.KeyboardMenuHotKey))
		{
			this.FullScreenOptionEvent(this);
		}
		if (!oldPrefs.SingleMouseExitHotKey.Equals(appPreferences.SingleMouseExitHotKey))
		{
			this.SingleMouseOptionEvent(this);
		}
		if (!oldPrefs.ConnectionExitHotKey.Equals(appPreferences.ConnectionExitHotKey))
		{
			this.ConnectionExitOptionEvent(this);
		}
	}

	private static HotKeyResolveInfoHolder[] ResolveHotKeys(XmlApplicationPreferences p)
	{
		HotKeyResolveInfoHolder[] array = new HotKeyResolveInfoHolder[3]
		{
			new HotKeyResolveInfoHolder(p.IsUserDefSingleMouseExitHotKey, p.GetSingleMouseExitHotKey, 'O'),
			new HotKeyResolveInfoHolder(p.IsUserDefKeyboardMenuHotKey, p.GetKeyboardMenuHotKey, 'M'),
			new HotKeyResolveInfoHolder(p.IsUserDefConnectionExitHotKey, p.GetConnectionExitHotKey, 'Q')
		};
		HashSet<string> hashSet = new HashSet<string>();
		HotKeyResolveInfoHolder[] array2 = array;
		foreach (HotKeyResolveInfoHolder hotKeyResolveInfoHolder in array2)
		{
			if (!hotKeyResolveInfoHolder.IsUserDefHotKeyFn())
			{
				continue;
			}
			if (!hashSet.Add(hotKeyResolveInfoHolder.GetHotKeyFn()))
			{
				HotKeyResolveInfoHolder[] array3 = array;
				foreach (HotKeyResolveInfoHolder hotKeyResolveInfoHolder2 in array3)
				{
					hotKeyResolveInfoHolder2.ResolvedHotKey = "Ctrl+Alt+" + hotKeyResolveInfoHolder2.DefHotKey;
				}
				return array;
			}
			hotKeyResolveInfoHolder.ResolvedHotKey = hotKeyResolveInfoHolder.GetHotKeyFn();
		}
		HotKeyResolveInfoHolder[] array4 = array;
		foreach (HotKeyResolveInfoHolder hotKeyResolveInfoHolder3 in array4)
		{
			if (!hotKeyResolveInfoHolder3.IsUserDefHotKeyFn() && hashSet.Add("Ctrl+Alt+" + hotKeyResolveInfoHolder3.DefHotKey))
			{
				hotKeyResolveInfoHolder3.ResolvedHotKey = "Ctrl+Alt+" + hotKeyResolveInfoHolder3.DefHotKey;
			}
		}
		HotKeyResolveInfoHolder[] array5 = array;
		foreach (HotKeyResolveInfoHolder hotKeyResolveInfoHolder4 in array5)
		{
			if (hotKeyResolveInfoHolder4.ResolvedHotKey == null)
			{
				string nextHotKey = GetNextHotKey(hotKeyResolveInfoHolder4.DefHotKey, hashSet);
				if (nextHotKey != null)
				{
					hashSet.Add(nextHotKey);
					hotKeyResolveInfoHolder4.ResolvedHotKey = nextHotKey;
				}
			}
		}
		return array;
	}

	private static string GetNextHotKey(char c, HashSet<string> userDefined)
	{
		string text = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
		CharEnumerator enumerator = text.GetEnumerator();
		while (enumerator.MoveNext() && !enumerator.Current.Equals(c))
		{
		}
		while (enumerator.MoveNext())
		{
			if (!userDefined.Contains("Ctrl+Alt+" + enumerator.Current))
			{
				return "Ctrl+Alt+" + enumerator.Current;
			}
		}
		enumerator = text.GetEnumerator();
		while (enumerator.MoveNext() && enumerator.Current != c)
		{
			if (!userDefined.Contains("Ctrl+Alt+" + enumerator.Current))
			{
				return "Ctrl+Alt+" + enumerator.Current;
			}
		}
		return null;
	}
}
