using System;

namespace Com.Raritan.KxGui.Preferences;

public class ConnectionScript : IComparable<ConnectionScript>
{
	public const int NameMaxLength = 80;

	public const int ValueMaxLength = 8192;

	private string _name;

	private string _virtseq;

	public string Name
	{
		get
		{
			return _name;
		}
		set
		{
			if (value == null)
			{
				throw new ArgumentNullException("Name", "Name Cannot be null");
			}
			if (value.Length > 80 || value.Length == 0)
			{
				throw new ArgumentOutOfRangeException("Name", "Name cannot be empty or more than " + 80 + " characters");
			}
			if (value.Contains("/"))
			{
				throw new ArgumentException("Name cannot contain / char");
			}
			_name = value;
		}
	}

	public string Type { get; set; }

	public string KeyboardType { get; set; }

	public string EditSequence { get; set; }

	public string VirtKeySequence
	{
		get
		{
			return _virtseq;
		}
		set
		{
			if (value == null)
			{
				throw new ArgumentNullException("VirtKeySequence", "VirtKeySequence Cannot be null");
			}
			if (value.Length > 8192 || value.Length == 0)
			{
				throw new ArgumentOutOfRangeException("VirtKeySequence", "VirtKeySequence cannot be empty or more than " + 8192 + " characters");
			}
			_virtseq = value;
		}
	}

	public string GetMacroSequence()
	{
		string[] array = VirtKeySequence.Split(new char[1] { ';' });
		string text = "";
		for (int i = 0; i < array.Length; i++)
		{
			char c = array[i][0];
			object obj = text;
			text = string.Concat(obj, c, (c == 's') ? " " : " p", array[i].Substring(1));
			if (i < array.Length - 1)
			{
				text += "&&";
			}
		}
		return text;
	}

	public override int GetHashCode()
	{
		return Name.GetHashCode();
	}

	public override bool Equals(object obj)
	{
		if (obj != null && (object)obj.GetType() == GetType())
		{
			return object.Equals(Name, ((ConnectionScript)obj).Name);
		}
		return false;
	}

	public override string ToString()
	{
		return "ConnectionScript : " + Name + " : " + VirtKeySequence;
	}

	public int CompareTo(ConnectionScript other)
	{
		return Name.CompareTo(other.Name);
	}
}
