using System;
using System.Windows.Forms;
using Com.Raritan.RcCore;

namespace Com.Raritan.KxGui.Preferences;

public class KeyboardMacro : IComparable<KeyboardMacro>
{
	public const int NameMaxLength = 80;

	public const int ValueMaxLength = 8192;

	private int _hotKey;

	private Com.Raritan.RcCore.d _macro;

	public string Name
	{
		get
		{
			return _macro.j();
		}
		set
		{
			if (value == null)
			{
				throw new ArgumentNullException("Name", "Name Cannot be null");
			}
			if (value.Length > 80 || value.Length == 0)
			{
				throw new ArgumentOutOfRangeException("Name", "Name cannot be empty or more than " + 80 + " characters");
			}
			if (value.Contains("/"))
			{
				throw new ArgumentException("Name cannot contain / char");
			}
			_macro.b(value);
		}
	}

	public int HotKey
	{
		get
		{
			return _hotKey;
		}
		set
		{
			if (value < -1 || value > 9)
			{
				throw new ArgumentOutOfRangeException("HotKey", "HotKey can be only from 0 to 9");
			}
			_hotKey = value;
		}
	}

	public string MacroSequence
	{
		get
		{
			return SequenceString(_macro.e());
		}
		set
		{
			if (value == null)
			{
				throw new ArgumentNullException("MacroSequence", "MacroSequence Cannot be null");
			}
			if (value.Length > 8192 || value.Length == 0)
			{
				throw new ArgumentOutOfRangeException("MacroSequence", "MacroSequence cannot be empty or more than " + 8192 + " characters");
			}
			_macro.b(GetSequence(value));
		}
	}

	public Com.Raritan.RcCore.d GetMacro()
	{
		return _macro;
	}

	public KeyboardMacro()
	{
		_macro = new Com.Raritan.RcCore.d("");
	}

	public KeyboardMacro(Com.Raritan.RcCore.d macro)
		: this(-1, macro)
	{
	}

	public KeyboardMacro(int hotKey, Com.Raritan.RcCore.d macro)
	{
		_macro = new Com.Raritan.RcCore.d(macro);
		HotKey = hotKey;
	}

	public KeyboardMacro(string name, int hotKey, int code)
	{
		_macro = new Com.Raritan.RcCore.d(name);
		HotKey = hotKey;
		_macro.b(code);
	}

	public KeyboardMacro(string name, int code)
		: this(name, -1, code)
	{
	}

	public KeyboardMacro(string name, string macroSequence)
		: this(name, -1, macroSequence)
	{
	}

	public KeyboardMacro(string name, int hotKey, string macroSequence)
	{
		_macro = new Com.Raritan.RcCore.d(name);
		HotKey = hotKey;
		MacroSequence = macroSequence;
	}

	public KeyboardMacro(KeyboardMacro macro)
		: this(macro._hotKey, macro._macro)
	{
	}

	public KeyboardMacro(ConnectionScript cs)
		: this(cs.Name, cs.GetMacroSequence())
	{
	}

	public override int GetHashCode()
	{
		return Name.GetHashCode();
	}

	public override bool Equals(object obj)
	{
		if (obj != null && (object)obj.GetType() == GetType())
		{
			return object.Equals(Name, ((KeyboardMacro)obj).Name);
		}
		return false;
	}

	public override string ToString()
	{
		return "KeyboardMacro : " + Name + " : " + HotKey + " : " + MacroSequence;
	}

	private static Com.Raritan.RcCore.g GetSequence(string macroSequence)
	{
		Com.Raritan.RcCore.g g = new Com.Raritan.RcCore.g();
		string[] array = macroSequence.Trim().Split(new string[1] { "&&" }, StringSplitOptions.RemoveEmptyEntries);
		string[] array2 = array;
		foreach (string text in array2)
		{
			string[] array3 = text.Trim().Split(new char[1] { ' ' });
			if (array3.Length != 2 || array3[0].Length != 1)
			{
				continue;
			}
			char c = array3[0][0];
			string text2 = array3[1];
			switch (c)
			{
			case 's':
				g.a(Convert.ToInt32(text2));
				break;
			case 'p':
			case 'r':
			{
				bool a_ = c == 'p';
				if (text2[0] == 'p')
				{
					g.a(Convert.ToInt32(text2.Substring(1)), a_);
				}
				else if (text2[0] == 'v')
				{
					g.a((Keys)Convert.ToInt32(text2.Substring(1)), a_);
				}
				break;
			}
			}
		}
		return g;
	}

	public static string SequenceString(Com.Raritan.RcCore.g sequence)
	{
		//IL_00a1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ab: Expected I4, but got Unknown
		bool flag = true;
		string text = "";
		foreach (Com.Raritan.RcCore.c item in sequence)
		{
			if (!flag)
			{
				text += "&&";
			}
			flag = false;
			if (item.e())
			{
				text = text + "s " + item.f();
			}
			else if (item.c().HasValue)
			{
				object obj = text;
				text = string.Concat(obj, item.d() ? "p" : "r", " v", (int)item.c().Value);
			}
			else
			{
				object obj2 = text;
				text = string.Concat(obj2, item.d() ? "p" : "r", " p", item.f());
			}
		}
		return text;
	}

	public int CompareTo(KeyboardMacro other)
	{
		return Name.CompareTo(other.Name);
	}
}
