using System;
using System.Collections;
using System.IO;
using System.Xml;
using System.Xml.Serialization;
using System.Xml.XPath;
using log4net;

namespace Com.Raritan.KxGui.Preferences;

public class KeyboardMacroManager
{
	private static readonly string Filepath = Path.Combine(Utils.HOME_DIR, "AkcKeyboardMacros.xml");

	private static readonly ILog Logger = LogManager.GetLogger(typeof(KeyboardMacroManager));

	private Hashtable _keyboardMacros = new Hashtable();

	public Hashtable KeyboardMacros
	{
		get
		{
			return (Hashtable)_keyboardMacros.Clone();
		}
		private set
		{
			_keyboardMacros = value;
		}
	}

	public KeyboardMacroManager()
	{
		KeyboardMacros = LoadKeyboardMacros();
	}

	public static Hashtable LoadKeyboardMacros()
	{
		return LoadKeyboardMacros(Filepath);
	}

	public static Hashtable LoadKeyboardMacros(string filepath)
	{
		//IL_0028: Unknown result type (might be due to invalid IL or missing references)
		//IL_002f: Expected O, but got Unknown
		Hashtable hashtable = new Hashtable();
		XmlDocument xmlDocument = Utils.GetXmlDocument(filepath);
		if (xmlDocument == null)
		{
			return hashtable;
		}
		string transformedXml = Utils.GetTransformedXml("ToKeyboardMacro.xslt", (IXPathNavigable)(object)xmlDocument);
		KeyboardMacroArray keyboardMacroArray;
		try
		{
			XmlSerializer val = new XmlSerializer(typeof(KeyboardMacroArray));
			keyboardMacroArray = (KeyboardMacroArray)val.Deserialize((TextReader)new StringReader(transformedXml));
		}
		catch (InvalidOperationException exception)
		{
			Logger.Warn("Error Reading KeyboardMacros", exception);
			return hashtable;
		}
		if (keyboardMacroArray.KeyboardMacros != null)
		{
			KeyboardMacro[] keyboardMacros = keyboardMacroArray.KeyboardMacros;
			foreach (KeyboardMacro keyboardMacro in keyboardMacros)
			{
				if (!hashtable.Contains(keyboardMacro.Name))
				{
					hashtable.Add(keyboardMacro.Name, keyboardMacro);
				}
			}
		}
		return hashtable;
	}

	public static Hashtable LoadConnectionScripts(string filepath)
	{
		//IL_0028: Unknown result type (might be due to invalid IL or missing references)
		//IL_002f: Expected O, but got Unknown
		Hashtable hashtable = new Hashtable();
		XmlDocument xmlDocument = Utils.GetXmlDocument(filepath);
		if (xmlDocument == null)
		{
			return hashtable;
		}
		string transformedXml = Utils.GetTransformedXml("ToConnectionScript.xslt", (IXPathNavigable)(object)xmlDocument);
		ConnectionScriptArray connectionScriptArray;
		try
		{
			XmlSerializer val = new XmlSerializer(typeof(ConnectionScriptArray));
			connectionScriptArray = (ConnectionScriptArray)val.Deserialize((TextReader)new StringReader(transformedXml));
		}
		catch (InvalidOperationException exception)
		{
			Logger.Warn("Error Reading ConnectionScripts", exception);
			return hashtable;
		}
		if (connectionScriptArray.ConnectionScripts != null)
		{
			ConnectionScript[] connectionScripts = connectionScriptArray.ConnectionScripts;
			foreach (ConnectionScript connectionScript in connectionScripts)
			{
				if (!hashtable.Contains(connectionScript.Name))
				{
					hashtable.Add(connectionScript.Name, new KeyboardMacro(connectionScript));
				}
			}
		}
		return hashtable;
	}

	public static Hashtable LoadKeyboardMacrosOrConnectionScripts(string filepath)
	{
		Hashtable hashtable = LoadKeyboardMacros(filepath);
		if (hashtable != null && hashtable.Count > 0)
		{
			return hashtable;
		}
		hashtable = LoadConnectionScripts(filepath);
		if (hashtable != null && hashtable.Count > 0)
		{
			return hashtable;
		}
		return new Hashtable();
	}

	public void PersistKeyboardMacros(Hashtable macros)
	{
		KeyboardMacros = (Hashtable)macros.Clone();
		PersistKeyboardMacros(macros, Filepath);
	}

	public static void PersistKeyboardMacros(Hashtable macros, string filepath)
	{
		XmlDocument prefernecesTemplate = Utils.GetPrefernecesTemplate("KeyboardMacrosTemplate.xml");
		XPathNavigator val = ((XmlNode)prefernecesTemplate).CreateNavigator().SelectSingleNode("preferences/root[@type='user']/node[@name='AkcKeyboardMacros']");
		KeyboardMacroArray keyboardMacroArray = new KeyboardMacroArray();
		KeyboardMacro[] array = new KeyboardMacro[macros.Count];
		macros.Values.CopyTo(array, 0);
		keyboardMacroArray.KeyboardMacros = array;
		string data = Utils.Serialize(keyboardMacroArray);
		val.AppendChild(Utils.GetTransformedXml("FromKeyboardMacro.xslt", data));
		try
		{
			prefernecesTemplate.Save(filepath);
		}
		catch (Exception exception)
		{
			Logger.Warn("Falied to persist " + filepath, exception);
			throw;
		}
	}
}
